<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'Estadísticas de SPIP',
	'stats_nom' => 'Estadísticas',
	'stats_slogan' => 'Administración de las estadísticas de SPIP',
];
